==> kamailio_5.1.2.orig.tar.gz: kamailio-5.1.2/src/modules/cdp/authstatemachine.h <==
/*
 * Copyright (C) 2012 Smile Communications, jason.penton@smilecoms.com
 * Copyright (C) 2012 Smile Communications, richard.good@smilecoms.com
 *
 * The initial version of this code was written by Dragos Vingarzan
 * (dragos(dot)vingarzan(at)fokus(dot)fraunhofer(dot)de and the
 * Fruanhofer Institute. It was and still is maintained in a separate
 * branch of the original SER. We are therefore migrating it to
 * Kamailio/SR and look forward to maintaining it from here on out.
 * 2011/2012 Smile Communications, Pty. Ltd.
 * ported/maintained/improved by
 * Jason Penton (jason(dot)penton(at)smilecoms.com and
 * Richard Good (richard(dot)good(at)smilecoms.com) as part of an
 * effort to add full IMS support to Kamailio/SR using a new and
 * improved architecture
 *
 * NB: Alot of this code was originally part of OpenIMSCore,
 * FhG Fokus.
 * Copyright (C) 2004-2006 FhG Fokus
 * Thanks for great work! This is an effort to
 * break apart the various CSCF functions into logically separate
 * components. We hope this will drive wider use. We also feel
 * that in this way the architecture is more complete and thereby easier
 * to manage in the Kamailio/SR environment
 *
 * This file is part of Kamailio, a free SIP server.
 *
 * Kamailio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * Kamailio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#ifndef __AUTHSTATEMACHINE_H
#define __AUTHSTATEMACHINE_H

#include "diameter_api.h"
#include "session.h"
#include "config.h"

void update_auth_session_timers(cdp_auth_session_t *x,AAAMessage *msg);

int auth_client_statefull_sm_process(cdp_session_t* auth, int event, AAAMessage* msg);
void auth_server_statefull_sm_process(cdp_session_t* auth, int event, AAAMessage* msg);

void auth_client_stateless_sm_process(cdp_session_t* s, int event, AAAMessage *msg);
void auth_server_stateless_sm_process(cdp_session_t* auth, int event, AAAMessage* msg);

void Send_ASA(cdp_session_t* s, AAAMessage* msg);

void Send_STR(cdp_session_t* s, AAAMessage* msg);
void Send_ASR(cdp_session_t* s, AAAMessage* msg);

#endif

==> kamailio_5.8.4.orig.tar.gz: kamailio-5.8.4/src/modules/cdp/authstatemachine.h <==
/*
 * Copyright (C) 2012 Smile Communications, jason.penton@smilecoms.com
 * Copyright (C) 2012 Smile Communications, richard.good@smilecoms.com
 *
 * The initial version of this code was written by Dragos Vingarzan
 * (dragos(dot)vingarzan(at)fokus(dot)fraunhofer(dot)de and the
 * Fruanhofer Institute. It was and still is maintained in a separate
 * branch of the original SER. We are therefore migrating it to
 * Kamailio/SR and look forward to maintaining it from here on out.
 * 2011/2012 Smile Communications, Pty. Ltd.
 * ported/maintained/improved by
 * Jason Penton (jason(dot)penton(at)smilecoms.com and
 * Richard Good (richard(dot)good(at)smilecoms.com) as part of an
 * effort to add full IMS support to Kamailio/SR using a new and
 * improved architecture
 *
 * NB: Alot of this code was originally part of OpenIMSCore,
 * FhG Fokus.
 * Copyright (C) 2004-2006 FhG Fokus
 * Thanks for great work! This is an effort to
 * break apart the various CSCF functions into logically separate
 * components. We hope this will drive wider use. We also feel
 * that in this way the architecture is more complete and thereby easier
 * to manage in the Kamailio/SR environment
 *
 * This file is part of Kamailio, a free SIP server.
 *
 * Kamailio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * Kamailio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#ifndef __AUTHSTATEMACHINE_H
#define __AUTHSTATEMACHINE_H

#include "diameter_api.h"
#include "session.h"
#include "config.h"

void update_auth_session_timers(cdp_auth_session_t *x, AAAMessage *msg);

int auth_client_statefull_sm_process(
		cdp_session_t *auth, int event, AAAMessage *msg);
void auth_server_statefull_sm_process(
		cdp_session_t *auth, int event, AAAMessage *msg);

void auth_client_stateless_sm_process(
		cdp_session_t *s, int event, AAAMessage *msg);
void auth_server_stateless_sm_process(
		cdp_session_t *auth, int event, AAAMessage *msg);

void Send_ASA(cdp_session_t *s, AAAMessage *msg);

void Send_STR(cdp_session_t *s, AAAMessage *msg);
void Send_ASR(cdp_session_t *s, AAAMessage *msg);

#endif
